==> haskell-regex-base-0.93.2-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
key: regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
abi: 6c4f2802d764f7f5a17e91732661aa5a
exposed: True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
import-dirs: /usr/lib/ghc-8.4.3/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    mtl-2.2.2
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.93.2-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-base
version: 0.93.2
id: regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
key: regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-base/
synopsis: Replaces/Enhances Text.Regex
description:
    Interface API for regex-posix,pcre,parsec,tdfa,dfa
category: Text
abi: 9101311609a045c4cf37f3bf32bdea5b
exposed: True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike
import-dirs: /usr/lib/ghc-8.6.1/site-local/regex-base-0.93.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/regex-base-0.93.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/regex-base-0.93.2
hs-libraries: HSregex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html: /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
